/*
 *  CPAPluginProtocols.h
 *  CocoaPacketAnalyzer
 *
 *  Formal Protocol Interface Version 2.00
 *
 */

#import <Foundation/Foundation.h>
#import <Cocoa/Cocoa.h>
@class CPAPlugInManagement;

#define CPAFindPredicateDisplayName			@"CPAFindPredicateDisplayName"
#define CPAFindPredicateLeftExpression	    @"CPAFindPredicateLeftExpression"
#define CPAFindPredicateAttrType			@"CPAFindPredicateAttrType"
/*  Notifications:
 *  if the plugin defaults changed you can inform any active document and refresh the views or clear analyzing caches to reprocess packets on next view.
 */
#define kReloadPacketsView			@"CPAReloadPacketsViewDataNotification"// Reload the packet view (does not reprocess packets - appearance only)
#define kReloadDetailsView			@"CPAReloadDetailsViewDataNotification"// Reload the detail view (reprocess the values)
#define kReloadConsoleView			@"CPAReloadConsoleViewDataNotification"// Reload the console view (reprocess the values)
#define kReloadDataSourcesList		@"CPAReloadDataSourcesListNotification"// Reload the data sources list view (does not reprocess packets - appearance only)
#define kReloadDataSourcesHead		@"CPAReloadDataSourcesHeadNotification"// Reload the data sources Header only (does not reprocess packets - appearance only)
#define kReloadProtocolStatistics	@"CPAReloadProtocolStatisticsNotification"// Reload the data sources protocol statistics (does not reprocess packets - appearance only)
#define kClearAnalyzingCaches		@"CPAClearAnalyzingCachesNotification"// Clear the analyzing cache in all packets to enable reprocessing



/// Plugin Principal Class
@protocol CPAPluginPrincipalClassProtocol<NSObject>
- (id) initWithPlugInManager:(CPAPlugInManagement*)plugInManager;
- (id) init;
+ (NSString *) pluginTitle;
+ (NSString *) pluginDescription;
+ (NSString *) pluginVersion;
+ (NSString *) pluginAuthor;
@end


/// Analyzer Model Class
@protocol CPAPluginAnalyzerProtocol<NSObject>
- (id) initWithBytes:(const void *)bytes length:(uint16_t)length packet:(id)packet;
- (uint16_t) protocolSize;
- (NSArray *) protocolNodes;
- (NSString *) nextProtocol;
- (NSString *) protocolName;
- (NSString *) protocolInfo;
- (BOOL) hasPayload;
@end

/// Plugin Preferences Controller Class
@protocol CPAPluginPreferencesProtocol <NSObject>
- (NSWindow*) preferencesSheet;
- (BOOL) usesColor;
- (NSColor*) protocolColor;
@end
