import Foundation
import CPAPlugInManager

extension CPATestProtocolAnalyzer {
    func generateNodes() -> [AnyHashable]? {
        let httpNode = CPANode.nodeWithName(NSLocalizedString("HTTP-Header", tableName: "LocalizableTestPlugIn", bundle: Bundle(for: CPATestPlugInWindowController.self), value: "", comment: "Analyzer: HTTP-Header"))
        httpNode.addChild(CPANode.nodeWithName(NSLocalizedString("Length", tableName: "LocalizableTestPlugIn", bundle: Bundle(for: CPATestPlugInWindowController.self), value: "", comment: "Analyzer: Type"), value: String(format: NSLocalizedString("%u bytes", tableName: "LocalizableTestPlugIn", bundle: Bundle(for: CPATestPlugInWindowController.self), value: "", comment: "Analyzer: Type"), protocolSize())))
        httpNode.addChild(CPANode.nodeWithName(NSLocalizedString("HTTP Method", tableName: "LocalizableTestPlugIn", bundle: Bundle(for: CPATestPlugInWindowController.self), value: "", comment: "Analyzer: Type"), value: "\(httpMethod)"))
        httpNode.headerLength 		= protocolSize()
        httpNode.headerLocation 	= 0
        httpNode.toolTip 			= protocolInfo()
        return [httpNode]
    }
}

@objc public class CPATestProtocolAnalyzer: NSObject, CPAPluginAnalyzerProtocol {
    // MARK: -
    // MARK: properties
    var httpMethod: HTTPMethod = .DATA
    var size: UInt16 = 0

    // MARK: -
    // MARK: init
    public required init!(bytes: UnsafeRawPointer!, length: UInt16, packet: Any!) {
        super.init()
        if length < 8 {
            httpMethod = .NA
            return
        } else {
            // this is just to demonstrate how to prg. the plugins. dont take this as a serious http-analysis
            size = length
            let ptr = UnsafeBufferPointer(start: bytes.assumingMemoryBound(to: UInt8.self), count: 8)
            let array: [UInt8] = Array(ptr)
            if let rawStrg = String(bytes: array, encoding: .ascii) {
                for aCase in HTTPMethod.allCases where (rawStrg.contains(aCase.rawValue)) {
                    httpMethod = aCase
                    break
                }
            }
        }
    }

    // MARK: -
    // MARK: protocol stubs
    @objc var httpMethodString: String {
       httpMethod.rawValue
    }
    public func protocolSize() -> UInt16 {
        size
    }
    public  func protocolNodes() -> [Any]! {
        self.generateNodes() ?? []
    }
    public  func nextProtocol() -> String? {
        nil
    }
    public func protocolName() -> String! {
        "HTTP"
    }
    public  func protocolInfo() -> String! {
        "\(httpMethod)"
    }
    public func hasPayload() -> Bool {
        true
    }
}
